==> apache-shenyu-2.6.0-src.zip: apache-shenyu-2.6.0-src/shenyu-admin/src/main/java/org/apache/shenyu/admin/model/query/ProxySelectorQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.model.query;

import org.apache.shenyu.admin.model.page.PageParameter;

import java.io.Serializable;

/**
 * this is proxy selector query.
 */
public class ProxySelectorQuery implements Serializable {

    private static final long serialVersionUID = 8058060154624248675L;

    /**
     * proxy selector name.
     */
    private String name;

    /**
     * page parameter.
     */
    private PageParameter pageParameter;

    /**
     * ProxySelectorQuery.
     */
    public ProxySelectorQuery() {

    }

    /**
     * ProxySelectorQuery.
     *
     * @param name          name
     * @param pageParameter pageParameter
     */
    public ProxySelectorQuery(final String name, final PageParameter pageParameter) {

        this.name = name;
        this.pageParameter = pageParameter;
    }

    /**
     * getName.
     *
     * @return name
     */
    public String getName() {

        return name;
    }

    /**
     * getPageParameter.
     *
     * @return pageParameter
     */
    public PageParameter getPageParameter() {

        return pageParameter;
    }
}

==> apache-shenyu-2.7.0.3-src.zip: apache-shenyu-2.7.0.3-src/shenyu-admin/src/main/java/org/apache/shenyu/admin/model/query/ProxySelectorQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.model.query;

import org.apache.shenyu.admin.model.page.PageParameter;

import java.io.Serializable;

/**
 * this is proxy selector query.
 */
public class ProxySelectorQuery implements Serializable {

    private static final long serialVersionUID = 8058060154624248675L;

    /**
     * proxy selector name.
     */
    private String name;

    /**
     * page parameter.
     */
    private PageParameter pageParameter;

    /**
     * namespace id.
     */
    private String namespaceId;

    /**
     * ProxySelectorQuery.
     */
    public ProxySelectorQuery() {

    }

    /**
     * ProxySelectorQuery.
     *
     * @param name          name
     * @param pageParameter pageParameter
     */
    public ProxySelectorQuery(final String name, final PageParameter pageParameter, final String namespaceId) {

        this.name = name;
        this.pageParameter = pageParameter;
        this.namespaceId = namespaceId;
    }

    /**
     * getName.
     *
     * @return name
     */
    public String getName() {

        return name;
    }

    /**
     * getPageParameter.
     *
     * @return pageParameter
     */
    public PageParameter getPageParameter() {

        return pageParameter;
    }

    /**
     * Gets the value of name.
     *
     * @return the value of name
     */
    public String getNamespaceId() {
        return namespaceId;
    }

    /**
     * Sets the namespaceId.
     *
     * @param namespaceId namespaceId
     */
    public void setNamespaceId(final String namespaceId) {
        this.namespaceId = namespaceId;
    }
}
